* Files in the directory needed to run the do file: wsilctaxben 
* (as obtained by running etbdataprocess.do and etbcompute)
*** THIS DO FILE COMPUTES CHARACTERISTICS OF THE TAX SYSTEM, SUCH AS THE AVERAGE AND MARGINAL TAX RATES,
*   AND PRESENTS THEM IN CHARTS AND TABLES
* 	It runs as a program (taxbenchars), in which the argument is a "reform", indicated by a letter on number
*   convention: 
* 	c = tax legislation of the dataset (as computed in dataprocess)
* 	0 = tax legislation as of running the program (status quo)
* 	1 = the proposed/approved reform comming up next (for our purpose, all tax changes coming into force in Jan 1, 2013
* 	2, 3, ... of course, there could be many alternative reforms to be evaluated
* 	each reform has to have parameters defined in etbparameters.do
* 	THE SECOND PART OF THE FILE PRODUCES SUMMARY STATISTICS ON THE INCOME AND TAX INFO IN SILC, MOSTLY USEFUL
* 	FOR RESEARCHER TO SEE WHAT'S IN THE DATA (NOT FOR PUBLICATION)

*clear
*set more off
*set memory 500m, permanently

* define the program
capture program drop taxbenchars
program define taxbenchars
args t 
	cd output_`t'
	use taxben_`t', clear 

	* 1. Compute total tax burdens from the taxes and benefits computed
	* They make economic sense only at the HH level
	* first, generate household level total gross income
	bysort domac: egen hhsginc_i_`t' = total(sginc_i_`t')
	label var hhsginc_i_`t' "Household super-gross income, `t'"

	*** Household net taxes (total taxes minus total benefits)
	gen hhnettax_i_`t'		= hhtotaltax_i_`t' - hhtotalben_`t'
	label var hhnettax_i_`t'	"Net household taxes on income (taxes on income - benefits), `t'"

	***	2. Construct ATRs - for different types of incomes***
	*** 2.a - Total taxes on work and business income as a share of economic (supergross) income
	*** further divided into taxes on work and non-work income
	gen ATR_w_`t' = totaltax_w_`t'/sginc_w_`t'
	gen ATR_b_`t' = totaltax_b_`t'/sginc_b_`t'
	gen ATR_i_`t' = totaltax_i_`t'/sginc_i_`t'

	label var ATR_w_`t'	 "Average tax rate on work income"
	label var ATR_b_`t'	 "Average tax rate on business income"
	label var ATR_i_`t'	 "Average tax rate on all income"

	*** 2.b - Total benefits and taxes of a HH as a share of economic (supergross) income
		
	gen hhATR_ben_`t' = hhtotalben_`t'/hhsginc_i_`t' 	
	gen hhATR_tax_`t' = hhtotaltax_i_`t'/hhsginc_i_`t' 	
	gen hhATR_all_`t' = hhnettax_i_`t'/hhsginc_i_`t' 

	label var hhATR_ben_`t'	 "HH-level average benefit rate on all income (HHs with positive income)"
	label var hhATR_tax_`t'	 "HH-level average tax rate on all income (HHs with positive income)"
	label var hhATR_all_`t'	 "HH-level average net tax rate on all income (HHs with positive income)"

	*** 2.c - Total taxes, benefits and net taxes as a share of net income of HH
	gen hhben_netinc_`t' = hhtotalben_`t'/hhnetinc_`t'
	gen hhtax_netinc_`t' = hhtotaltax_i_`t'/hhnetinc_`t'
	gen hhall_netinc_`t'= hhnettax_i_`t'/hhnetinc_`t'
	
	label var hhben_netinc_`t' "HH-level total benefits as a share of net income"
	label var hhtax_netinc_`t' "HH-level total taxes as a share of net income"
	label var hhall_netinc_`t' "HH-level net taxes as a share of net income"
	
	save taxbenchars_`t', replace
*** 3. Program for MTR's 
	/* Outline: 
	- outputs: individual-specifc MTRs going through taxes, benefis, and overall net tax
	- MTR through taxes separated for work and business income, and work separated further into formal and informal
	- a "summary" MTR on work income weighs the share of formal/informal income
	- MTR through benefits should not distinguish between work and business income (unless there indeed are benefits that are for employees only)
	- the computation calculates the sum of taxes at the household level after an increase in the individual's income, 
	- and compares with the sum of taxes at the hh level before the increase of the individual's income
	- the computation is iterated by member id - always need to compute his tax and all the other hh members taxes in response to a change in his income
	- then merge te dataset	to have one MTR per person
	- in calculation, use the taxcompute program - this assures using the same formula, eliminating the risk of mistakes, no need to make two corrections
		*/ 
	
	* MTR's cannot be computed for tax regime `c' because we do not compute taxes out of parameters in regime `c'
	* Hence it is computed only for tax regimes other than `c' (using "if" programming command)
	cd ..
	if "`t'" ~= "c" {
		* 3.0 Run a loop for different sources of income (s) 
		*capture mkdir tempfiles
		foreach s of varlist ginc_wf ginc_wi ginc_bm ginc_bs {
			* 3.1 Loop over member id's
			foreach i of numlist 1 2 3 4 5 6 7 8 9 10 81 91 92 93 94 {
				use taxben, clear
				* 3.2. Add 1000 to the income source of the looped member id
				* and save the dataset for the calculation for each income sources and member id
				replace `s' = `s'+ 1000 if osoba == `i'
				save mtr_`s'_`i'_`t', replace
				* 3.3. compute the tax and benefits for everybody as a fn of the (incrememted) income
				* for the tax regime chosen
				* !!! assure consistency with bencompute!!!
				taxcompute `t' mtr_`s'_`i'_`t' mtr_`s'_`i'_`t' 
				bencompute `t' mtr_`s'_`i'_`t' mtr_`s'_`i'_`t'
				* 3.4. asign the computed total household taxes and benefits to the person whose MTR is computed 
				gen hhtotaltax_i_mtr_`s'_`t' = hhtotaltax_i_`t' if osoba == `i'
				gen hhtotalben_mtr_`s'_`t' = hhtotalben_`t' if osoba == `i' 
				* Rename the super-gross income - the MTR will be on the change in the super-gross, not gross
				* hence we need to know by how much the super-gross changes if the gross income increases by 1000
				* must be defined separately for each income source and tax regime
				rename sginc_i_`t' sginc_i_mtr_`s'_`t'
				label var sginc_i_mtr_`s'_`t' "super-gross income from work if gross income `s' is increased by 1000"
				
				* Keep the only variables needed for merging:
				* - hh and person id's 
				* - the new household total taxes and benefits
				* - the super-gross incomes
				keep domac osoba hhtotaltax_i_mtr_`s'_`t' hhtotalben_mtr_`s'_`t' sginc_i_mtr_`s'_`t'
				keep if osoba == `i' 
				sort domac osoba
				cd output_`t'
				erase mtr_`s'_`i'_`t'.dta
				cd ..
				save mtr_`s'_`i'_`t',replace
			}
		}
	
		* 3.5. Merge the computation files back to the main file
		cd output_`t'
		use taxbenchars_`t', clear
		sort domac osoba
		save taxben_mtr, replace
		cd ..
		* merge over person id's and income sources
		foreach s of varlist ginc_wf ginc_wi ginc_bm ginc_bs {
			foreach i of numlist 1 2 3 4 5 6 7 8 9 10 81 91 92 93 94{
			merge 1:1 domac osoba using mtr_`s'_`i'_`t', update gen(_merge_`i'_`s')
			erase mtr_`s'_`i'_`t'.dta
			}
		}
		cd output_`t'
		save taxben_mtr, replace
		
		* 3.6. Generate the MTR's
		* loop over income sources
		foreach s of varlist ginc_wf ginc_wi ginc_bm ginc_bs {
			g mtr_tax_`s'_`t' = (hhtotaltax_i_mtr_`s'_`t' - hhtotaltax_i_`t')/(sginc_i_mtr_`s'_`t' - sginc_i_`t')
			g mtr_ben_`s'_`t' = -(hhtotalben_mtr_`s'_`t' - hhtotalben_`t')/(sginc_i_mtr_`s'_`t' - sginc_i_`t')
			g mtr_all_`s'_`t' =  mtr_tax_`s'_`t' + mtr_ben_`s'_`t' 
		}
		label var mtr_tax_ginc_wf_`t' "Marginal tax rate on formal work income, `t'"
		label var mtr_ben_ginc_wf_`t' "Marginal benefit withdrawal rate on formal work income, `t'"
		label var mtr_all_ginc_wf_`t' "Full marginal tax rate on formal work income, `t'"
		
		label var mtr_tax_ginc_wi_`t' "Marginal tax rate on informal work income, `t'"
		label var mtr_ben_ginc_wi_`t' "Marginal benefit withdrawal rate on informal work income, `t'"
		label var mtr_all_ginc_wi_`t' "Full marginal tax rate on informal work income, `t'"
	
		label var mtr_tax_ginc_bm_`t' "Marginal tax rate on main business income, `t'"
		label var mtr_ben_ginc_bm_`t' "Marginal benefit withdrawal rate on main business income, `t'"
		label var mtr_all_ginc_bm_`t' "Full marginal tax rate on main business income, `t'"
		
		label var mtr_tax_ginc_bs_`t' "Marginal tax rate on secondary business income, `t'"
		label var mtr_ben_ginc_bs_`t' "Marginal benefit withdrawal rate on secondary business income, `t'"
		label var mtr_all_ginc_bs_`t' "Full marginal tax rate on secondary business income, `t'"
		
		
		* Generate MTR on all work income (combining formal and informal)
		* Generate full MTR (business and work)
		* by weighting with the income shares
		* loop over concepts of MTR
		local concepts "tax ben all"
		foreach x of local concepts {
			g mtr_`x'_w_`t' = max(-2, min(mtr_`x'_ginc_wf_`t'*shr_wf_ginc_w + mtr_`x'_ginc_wi_`t'*shr_wi_ginc_w, 2))   
			g mtr_`x'_b_`t' = max(-2, min(mtr_`x'_ginc_bm_`t'*shr_bm_ginc_b + mtr_`x'_ginc_bs_`t'*shr_bs_ginc_b, 2))
			g mtr_`x'_i_`t' = max(-2, min(mtr_`x'_w_`t'*shr_w_ginc + mtr_`x'_b_`t'*shr_b_ginc, 2))
		}
		label var mtr_tax_w_`t' "Marginal tax rate on work income, `t'"
		label var mtr_ben_w_`t' "Marginal benefit withdrawal rate on work income, `t'"
		label var mtr_all_w_`t' "Full marginal tax rate on work income, `t'"
		label var mtr_tax_b_`t' "Marginal tax rate on business income, `t'"
		label var mtr_ben_b_`t' "Marginal benefit withdrawal rate on business income, `t'"
		label var mtr_all_b_`t' "Full marginal tax rate on business income, `t'"
		label var mtr_tax_i_`t' "Marginal tax rate on all incomes, `t'"
		label var mtr_ben_i_`t' "Marginal benefit withdrawal rate on all incomes, `t'"
		label var mtr_all_i_`t' "Full marginal tax rate on all incomes, `t'"	
	
		save taxben_mtr, replace
		save taxbenchars_`t', replace

	}
	* end of loop for MTR's (for tax regimes other than `c')

*** 4. Program for PTR's 

	* PTR's cannot be computed for tax regime `c' because we do not compute taxes out of parameters in regime `c'
	* Hence it is computed only for tax regimes other than `c' (using "if" programming command)
	cd ..
	if "`t'" != "c" {
			* 4.0 Loop for different sources of income (s) 
			*capture mkdir tempfiles
			foreach s of varlist ginc_wf ginc_wi ginc_bm ginc_bs {
				* Loop over full or part time work (imputed waqe for non-working either for full or part time)
				if "`s'"=="ginc_wf" {
				local list "f p"
				}
				else {
				local list "f"
				}
				foreach m of local list {
					* Loop over member id's
					foreach i of numlist 1 2 3 4 5 6 7 8 9 10 81 91 92 93 94 {
					use taxben, clear
					* 4.2.a Change the working income of the looped member id to zero (for working)
					display "`s'"
					replace `s' = 0 		if osoba==`i' & p!=0
					replace mes_zam = 0		if osoba==`i' & p!=0 & ("`s'"=="ginc_wf" |"`s'"=="ginc_wi")
					replace mes_podn = 0	if osoba==`i' & p!=0 & ("`s'"=="ginc_bm" | "`s'"=="ginc_bs")
					* 4.2.b Change the working income of the looped member id to imputed wage (for non-working)
					replace `s' = mzda_f if osoba==`i' & p==0 & "`s'"=="ginc_wf" & "`m'"=="f"
					replace `s' = mzda_p if osoba==`i' & p==0 & "`s'"=="ginc_wf" & "`m'"=="p"
					replace mes_zam = 12	if osoba==`i' & p==0 & "`s'"=="ginc_wf"
					save ptr_`s'_`m'_`i'_`t', replace
					
					* 4.3. compute the tax and benefits for everybody as a fn of the (incrememted) income
					taxcompute `t' ptr_`s'_`m'_`i'_`t' ptr_`s'_`m'_`i'_`t' 
					bencompute `t' ptr_`s'_`m'_`i'_`t' ptr_`s'_`m'_`i'_`t'
					* 4.4. new super gross income 
					rename sginc_i_`t' sginc_i_ptr_`s'_`m'_`t'
					label var sginc_i_ptr_`s'_`m'_`t' "super-gross income from work if gross income `s' is replaced by 0 (working) or by imputed wage (non-working)"
					* 4.5. asign the computed total household taxes and benefits to the person whose MTR is computed 
					gen hhtotaltax_i_ptr_`s'_`m'_`t' 	= hhtotaltax_i_`t' 	if osoba == `i'
					gen hhtotalben_ptr_`s'_`m'_`t' 		= hhtotalben_`t' 	if osoba == `i'  
					* Keep the only variables needed for merging:
					* - hh and person id's 
					* - the new household total taxes and benefits
					keep domac osoba hhtotaltax_i_ptr_`s'_`m'_`t' hhtotalben_ptr_`s'_`m'_`t' sginc_i_ptr_`s'_`m'_`t'
					keep if osoba == `i' 
					sort domac osoba
					cd output_`t'
					erase ptr_`s'_`m'_`i'_`t'.dta
					cd ..
					save ptr_`s'_`m'_`i'_`t', replace //these datasets (ptr_*) need to be at two places - in the main TAXBEN_SILC folder, because that is where the taxcompute above takes the input file from, and in the folder output_`t' as well, because it is where the bencompute saves the output file
				}
				}
			}
				
		
		* 4.5. Merge the computation files back to the main file
		cd output_`t'
		use taxbenchars_`t', clear
		sort domac osoba
		save taxben_ptr, replace
		* merge over person id's and income sources
		cd ..
		foreach s of varlist ginc_wf ginc_wi ginc_bm ginc_bs {
			if "`s'"=="ginc_wf" {
			local list "f p"
			}
			else {
			local list "f"
			}
			foreach m of local list {
				foreach i of numlist 1 2 3 4 5 6 7 8 9 10 81 91 92 93 94 {
				merge 1:1 domac osoba using ptr_`s'_`m'_`i'_`t', update nogen
				erase ptr_`s'_`m'_`i'_`t'.dta
				}
			}
		}
		cd output_`t'
		save taxben_ptr, replace
		
		* 4.6. Generate the PTR's
		* loop over income sources
	
		foreach s of varlist ginc_wf ginc_wi ginc_bm ginc_bs {
			if "`s'"=="ginc_wf" {
			local list "f p"
			}
			else {
			local list "f"
			}
		foreach m of local list {
			g ptr_tax_`s'_`m'_`t' = (hhtotaltax_i_`t' - hhtotaltax_i_ptr_`s'_`m'_`t')/(sginc_i_`t' - sginc_i_ptr_`s'_`m'_`t')
			g ptr_ben_`s'_`m'_`t' = (hhtotalben_ptr_`s'_`m'_`t' - hhtotalben_`t')/(sginc_i_`t' - sginc_i_ptr_`s'_`m'_`t')
			g ptr_all_`s'_`m'_`t' = ptr_tax_`s'_`m'_`t' + ptr_ben_`s'_`m'_`t'
			replace ptr_tax_`s'_`m'_`t' = 0 if ptr_tax_`s'_`m'_`t'==.
			replace ptr_ben_`s'_`m'_`t' = 0 if ptr_ben_`s'_`m'_`t'==.
			replace ptr_all_`s'_`m'_`t' = 0 if ptr_all_`s'_`m'_`t'==.
		}
		}
		* replace part-time PTR for those working with missing values - because part-time job PTR is relevant only for non-working (above the part-time PTR for working is defined to be the same as full-time PTR)
		replace ptr_tax_ginc_wf_p_`t' = . if p!=0
		replace ptr_ben_ginc_wf_p_`t' = . if p!=0
		replace ptr_all_ginc_wf_p_`t' = . if p!=0
		
		label var ptr_tax_ginc_wf_f_`t' "Participation tax rate on formal full-time work income, `t'"
		label var ptr_ben_ginc_wf_f_`t' "Participation benefit withdrawal rate on formal full-time work income, `t'"
		label var ptr_all_ginc_wf_f_`t' "Full participation tax rate on formal full-time work income, `t'"
		
		label var ptr_tax_ginc_wf_p_`t' "Participation tax rate on formal part-time work income, `t'"
		label var ptr_ben_ginc_wf_p_`t' "Participation benefit withdrawal rate on formal part-time work income, `t'"
		label var ptr_all_ginc_wf_p_`t' "Full participation tax rate on formal part-time work income, `t'"
		
		label var ptr_tax_ginc_wi_f_`t' "Participation tax rate on informal work income, `t'"
		label var ptr_ben_ginc_wi_f_`t' "Participation benefit withdrawal rate on informal work income, `t'"
		label var ptr_all_ginc_wi_f_`t' "Full participation tax rate on informal work income, `t'"
	
		label var ptr_tax_ginc_bm_f_`t' "Participation tax rate on main business income, `t'"
		label var ptr_ben_ginc_bm_f_`t' "Participation benefit withdrawal rate on main business income, `t'"
		label var ptr_all_ginc_bm_f_`t' "Full participation tax rate on main business income, `t'"
		
		label var ptr_tax_ginc_bs_f_`t' "Participation tax rate on secondary business income, `t'"
		label var ptr_ben_ginc_bs_f_`t' "Participation benefit withdrawal rate on secondary business income, `t'"
		label var ptr_all_ginc_bs_f_`t' "Full participation tax rate on secondary business income, `t'"

		
		* Generate PTR on all work income (combining formal and informal)
		* Generate full PTR (business and work)
		* by weighting with the income shares
		* loop over concepts of ptr
		local concepts "tax ben all"
		foreach x of local concepts {
			g ptr_`x'_w_`t' = max(-2, min(ptr_`x'_ginc_wf_f_`t' * shr_wf_ginc_w 	+ ptr_`x'_ginc_wi_f_`t' * shr_wi_ginc_w, 2)) 	if p!=0 //so that this is defined only for working
			g ptr_`x'_b_`t' = max(-2, min(ptr_`x'_ginc_bm_f_`t' * shr_bm_ginc_b 	+ ptr_`x'_ginc_bs_f_`t' * shr_bs_ginc_b, 2))		if p!=0
			g ptr_`x'_i_`t' = max(-2, min(ptr_`x'_w_`t' * shr_w_ginc 				+ ptr_`x'_b_`t' * shr_b_ginc, 2))				if p!=0
			
			g ptr_`x'_w_p_`t' = max(-2, min(ptr_`x'_ginc_wf_p_`t', 2)) if p==0 //only for the non-working
			g ptr_`x'_w_f_`t' = max(-2, min(ptr_`x'_ginc_wf_f_`t', 2)) if p==0 //only for the non-working
			
		}
		
		label var ptr_tax_w_f_`t' "Participation tax rate for non-working on full-time work income, `t'"
		label var ptr_ben_w_f_`t' "Participation benefit withdrawal rate for non-working on full-time work income, `t'"
		label var ptr_all_w_f_`t' "Full participation tax rate for non-working on full-time work income, `t'"
		
		label var ptr_tax_w_p_`t' "Participation tax rate for non-working on part-time work income, `t'"
		label var ptr_ben_w_p_`t' "Participation benefit withdrawal rate for non-working on part-time work income, `t'"
		label var ptr_all_w_p_`t' "Full participation tax rate for non-working on part-time work income, `t'"
						
		label var ptr_tax_w_`t' "Participation tax rate for working on actual work income, `t'"
		label var ptr_ben_w_`t' "Participation benefit withdrawal rate for working on actual work income, `t'"
		label var ptr_all_w_`t' "Full participation tax rate for working on actual work income, `t'"
		
		label var ptr_tax_b_`t' "Participation tax rate for working on actual business income, `t'"
		label var ptr_ben_b_`t' "Participation benefit withdrawal rate for working on actual business income, `t'"
		label var ptr_all_b_`t' "Full participation tax rate for working on actual business income, `t'"
			
		label var ptr_tax_i_`t' "Participation tax rate for working on all incomes, `t'"
		label var ptr_ben_i_`t' "Participation benefit withdrawal rate for working on all incomes, `t'"
		label var ptr_all_i_`t' "Full participation tax rate for working on all incomes, `t'"	
		
		save taxben_ptr, replace
		save taxbenchars_`t', replace

	}
	* end of loop for PTR's (for tax regimes other than `c')
	
	***Cutting tails for plotting***
	*** some very extreme values of ATR or MTR due to particular circumstances (??? or errors?) - isolate them out
	*** keep only people above the 1st and below 98th percentile of ATR
	foreach v of varlist ATR_w_`t' ATR_b_`t' ATR_i_`t' hhATR_ben_`t' hhATR_tax_`t' hhATR_all_`t' mtr_tax_w_`t' mtr_all_w_`t' mtr_tax_b_`t' mtr_all_b_`t' mtr_tax_i_`t' mtr_ben_i_`t' mtr_all_i_`t' ptr_tax_w_f_`t' ptr_tax_w_p_`t' ptr_tax_w_`t' ptr_ben_w_f_`t' ptr_ben_w_p_`t' ptr_ben_w_`t' ptr_all_w_f_`t' ptr_all_w_p_`t' ptr_all_w_`t' ptr_tax_b_`t' ptr_ben_b_`t' ptr_all_b_`t' ptr_tax_i_`t' ptr_ben_i_`t' ptr_all_i_`t'{
		centile `v', centile(1 99)
		scalar `v'low = r(c_1)
		scalar `v'high = r(c_2)  
		gen p`v' = `v' if (`v' >=`v'low & `v' <= `v'high) | (`v'>-0.51 &`v'<1.01)
	}
	
	*** 5. DEFINE DECILE INDICATORS, DECILE AVERAGES, DECILE SHARES, INTERVALS OF TAX RATES 
	*** AND SIMILAR VARIABLES THAT ARE USED IN TABLES	
		
	*** 5.1 Aggregate taxes, benefits, incomes, and number of taxpayers
		local sources "w b i"  // to loop over work, business, and all incomes
	* cannot use weights with egen, so need to multiply by the weights, and define the number of people in the decile
	foreach s of local sources {
		g we_ginc_`s' 				= round(ginc_`s'*(round(pkoef)))
		g we_totaltax_`s'_`t' 		= totaltax_`s'_`t'*(round(pkoef))
		**DEL egen agg_ntaxpayers_`s'		= total(rpkoef) 				if ginc_`s'>inclb
		egen agg_ginc_`s' 			= total(we_ginc_`s') 			if ginc_`s'>inclb
		egen agg_totaltax_`s'_`t' 	= total(we_totaltax_`s'_`t')	if ginc_`s'>inclb
		label var we_ginc_`s' 			"gross income, s=`s' , multiplied by the weight"
		label var we_totaltax_`s'_`t' 	"total taxes on income, s=`s', t=`t', multiplied by the weight"
		label var agg_ginc_`s' 			"aggregate gross income, s=`s'"
		label var agg_totaltax_`s'_`t'	"aggregate taxes on earnings, s=`s', t=`t'"
		**DEL label var agg_ntaxpayers_`s'	"number of taxpayers with non-negligible income, s=`s'"
		}
	
	* Benefits are at HH level (hhtotalben_`t' is defined for each HH member - take only the value of the head of household)
	* as there are no household weights in SILC, we have to use personal weights of the head of household to adjust benefit amounts
	
	* restrict all HH statistics to non-pensioner households 
	
		g we_hhtotaltax_`t'		= hhtotaltax_i_`t'*(round(pkoef)) if vztah==1 & hhnonpen==1
		g we_hhtotalben_`t' 	= hhtotalben_`t'*(round(pkoef))	if vztah==1 & hhnonpen==1
		g we_hhnettax_`t' 		= hhnettax_i_`t'*(round(pkoef))	if vztah==1 & hhnonpen==1
		
		label var we_hhtotaltax_`t' "total taxes of a household, t=`t', multiplied by the weight"
		label var we_hhtotalben_`t' "total benefits of a household, t=`t', multiplied by the weight"
		label var we_hhnettax_`t' 	"net taxes of a household, t=`t', multiplied by the weight"
	
	*** 5.2. Taxes and tax shares by income deciles 
	* 
	*** 5.2.1. Tax and income decile at the individual level 
	* define GROSS income deciles and their percentile cut-offs
	* To construct the shares, define for each decile
	* - total taxes and total income within the decile
	* - divide those by the aggregate taxes or incomes to get the decile shares
	* - for overall decile shares, construct the share of business income in that decile
	local sources "w b i" 
	foreach s of local sources {
		xtile dec_ginc_`s' 		= ginc_`s' if ginc_`s' > inclb $wep, nquantiles(10)
		pctile ptile_ginc_`s' 	= ginc_`s' if ginc_`s' > inclb $wep, nquantiles(10)
		
		bysort dec_ginc_`s': egen dec_aginc_`s' 	  	= total(we_ginc_`s')		 if ginc_`s'>inclb
		bysort dec_ginc_`s': egen dec_atotaltax_`s'_`t' = total(we_totaltax_`s'_`t') if ginc_`s'>inclb
		g dec_shr_ginc_`s' 			= dec_aginc_`s'/agg_ginc_`s'
		g dec_shr_totaltax_`s'_`t' 	= dec_atotaltax_`s'_`t'/agg_totaltax_`s'_`t'
	}
	
		label var dec_ginc_w 			"work income decile"
		label var dec_ginc_b 			"business income decile"
		label var dec_ginc_i 			"income decile"
		label var dec_aginc_w	 		"aggregate gross work income in a decile"
		label var dec_aginc_b	 		"aggregate gross business income in a decile"
		label var dec_aginc_i	 		"aggregate gross income in a decile"
		label var dec_atotaltax_w_`t'	"aggregate taxes on work income in a decile, t=`t'"
		label var dec_atotaltax_b_`t'	"aggregate taxes on business in a decile, t=`t'"
		label var dec_atotaltax_i_`t'	"aggregate taxes on income in a decile, t=`t'"
		label var dec_shr_ginc_w 			"decile share in work income"
		label var dec_shr_ginc_b			"decile share in business income"
		label var dec_shr_ginc_i 			"decile share in income"
		label var dec_shr_totaltax_w_`t'	"decile share in taxes on work income, t=`t'"
		label var dec_shr_totaltax_b_`t'	"decile share in taxes on business income, t=`t'"
		label var dec_shr_totaltax_i_`t'	"decile share in taxes on income, t=`t'"
	
	bysort dec_ginc_i: egen dec_i_aginc_w = total(we_ginc_w) if ginc_w > inclb
	bysort dec_ginc_i: egen dec_i_aginc_b = total(we_ginc_b) if ginc_b > inclb
	g dec_shr_i_ginc_w = dec_i_aginc_w/dec_aginc_i
	g dec_shr_i_ginc_b = dec_i_aginc_b/dec_aginc_i
	
	label var dec_shr_i_ginc_w "Share of work income in all income decile"
	label var dec_shr_i_ginc_b "Share of business income in all income decile"
		
	* 5.2.2. Benefits and net taxes: income deciles at household level (only based on total income)
	bysort domac: egen hhwe_ginc_i = total(we_ginc_i)
	
		* income, taxes and benefits per household unit(OECD definition)
		gen hhginc_perunit = hhginc_i/sj
		gen hhnetinc_perunit_`t' = hhnetinc_`t'/sj
		gen hhaftertinc_perunit_`t' = hhaftertinc_`t'/sj
		gen hhbeninc_perunit_`t' = hhbeninc_`t'/sj
		gen hhweginc_perunit = hhwe_ginc_i/sj
		
		gen hhtotaltax_perunit_`t'	= hhtotaltax_i_`t'/sj
		gen hhtotalben_perunit_`t'	= hhtotalben_`t'/sj
		gen hhnettax_perunit_`t'	= hhnettax_i_`t'/sj

		gen we_hhtotaltax_perunit_`t' = we_hhtotaltax_`t'/sj
		gen we_hhtotalben_perunit_`t' = we_hhtotalben_`t'/sj
		gen we_hhnettax_perunit_`t'	  = we_hhnettax_`t'/sj
		
		* benefit amounts per unit, only for positive amounts (so that average does not include zeros)
		gen brth_grhh_perunit_`t' = brth_grhh_`t'/sj 	if brth_grhh_`t'>0
		gen mat_benhh_perunit_`t' = mat_benhh_`t'/sj 	if mat_benhh_`t'>0
		gen ch_allhh_perunit_`t' = ch_allhh_`t'/sj		if ch_allhh_`t'>0
		gen hous_benhh_perunit_`t' = hous_benhh_`t'/sj	if hous_benhh_`t'>0
		gen liv_allhh_perunit_`t' = liv_allhh_`t'/sj	if liv_allhh_`t'>0
		gen hous_suplhh_perunit_`t' = hous_suplhh_`t'/sj if hous_suplhh_`t'>0
		gen unempl_benhh_perunit_`t' = unempl_benhh_`t'/sj if unempl_benhh_`t'>0
		gen par_allhh_perunit_`t' = par_allhh_`t'/sj	if par_allhh_`t'>0
		gen other_benhh_perunit_`t' = other_benhh_`t'/sj if other_benhh_`t'>0
		
		label var hhginc_perunit 			"Household gross income per OECD unit"
		label var hhweginc_perunit 			"Household gross income per OECD unit weighted"
		label var hhtotaltax_perunit_`t' 	"Total household taxes pair per OECD unit, t=`t'"
		label var hhtotalben_perunit_`t' 	"Total household benefits received per OECD unit, t=`t'"
		label var hhnettax_perunit_`t' 		"Household net taxes paid per OECD unit, t=`t'"
		label var we_hhtotaltax_perunit_`t' "Household total taxes per OECD unit weighted, t=`t'"
		label var we_hhtotalben_perunit_`t' "Total household benefits received per OECD unit weighted, t=`t'"
		label var we_hhnettax_perunit_`t' 	"Household net taxes paid per OECD unit weighted, t=`t'"
		
		* dummy for taxes and benefits received being positive
		gen hhtotaltax_pos_`t' = (hhtotaltax_i_`t' >0)
		gen hhtotalben_pos_`t' = (hhtotalben_`t'   >0)
		gen hhnettax_pos_`t'   = (hhnettax_i_`t'   >0)
		
		* dummy for benefits received being positive
		gen brth_grhh_pos_`t' = (brth_grhh_`t'>0)
		gen mat_benhh_pos_`t' = (mat_benhh_`t'>0)
		gen ch_allhh_pos_`t' = (ch_allhh_`t'>0)
		gen hous_benhh_pos_`t' = (hous_benhh_`t'>0)
		gen liv_allhh_pos_`t' = (liv_allhh_`t'>0)
		gen hous_suplhh_pos_`t' = (hous_suplhh_`t'>0)
		gen unempl_benhh_pos_`t' = (unempl_benhh_`t'>0)
		gen par_allhh_pos_`t' = (par_allhh_`t'>0)
		gen other_benhh_pos_`t' = (other_benhh_`t'>0)
		
		* replace taxes paid and benefits received with missing if it is zero (to have all summary statistics based on positive values only)
		* not for net taxes - we are equally interested in positive and negative numbers)
		gen     hhtotaltax_perunit2_`t' = hhtotaltax_perunit_`t'
		gen 	hhtotalben_perunit2_`t' = hhtotalben_perunit_`t'
		gen		hhnettax_perunit2_`t'   = hhnettax_perunit_`t'
		replace hhtotaltax_perunit2_`t' = . if hhtotaltax_perunit_`t'==0
		replace hhtotalben_perunit2_`t' = . if hhtotalben_perunit_`t'==0
		replace hhnettax_perunit2_`t'   = . if hhnettax_perunit_`t'  <=0
		gen     hhtotaltax2_i_`t'	= hhtotaltax_i_`t'
		gen 	hhtotalben2_`t' 	= hhtotalben_`t'
		gen		hhnettax2_`t'   	= hhnettax_i_`t'
		replace hhtotaltax2_i_`t'	= . if hhtotaltax_i_`t'==0
		replace hhtotalben2_`t' 	= . if hhtotalben_`t'==0
		replace hhnettax2_`t'   	= . if hhnettax_i_`t'<=0
		
		local bentypes "brth_gr mat_ben ch_all hous_ben liv_all hous_supl unempl_ben par_all other_ben" 
		foreach s of local bentypes {
		gen 	`s'hh_perunit2_`t' = `s'hh_perunit_`t'
		replace `s'hh_perunit2_`t' =  . 				if `s'hh_pos_`t'==0
		}
		
		label var hhtotaltax_pos_`t'		"Dummy for household paying positive taxes, t=`t'"
		label var hhtotalben_pos_`t' 		"Dummy for household receiving positive benefits, t=`t'"
		label var hhnettax_pos_`t'			"Dummy for households pay more in taxes than they receive in benefits, t=`t'"
		label var hhtotaltax_perunit2_`t' 	"Total household taxes per OECD unit, positive values only, t=`t'"
		label var hhtotalben_perunit2_`t'	"Total household benefits per OECD unit, positive values only, t=`t'"
		label var hhnettax_perunit2_`t'		"Total housheold net taxes per OECD unit, positive values only, t=`t'"
				
		* income decile based on per unit household income
		xtile dec_hhginc_pu 	= hhginc_perunit 	if vztah==1 & hhnonpen==1 $wep, nquantiles(10) //this is used in tables that describe amount of benefits and taxes per household unit, deciles have to be defined for head of households only, because otherwise big families are there more than once
		xtile dec_hhginc 		= hhginc_i 			if vztah==1 & hhnonpen==1 $wep, nquantiles(10) //this is used in tables that describe amount of benefits and taxes per household unit
		
		* aggregate income and benefits in a decile
			* here, we need to compute decile sums over all household members, not only heads of households (see below), but the deciles are defined for heads only - impute decile number to other households members as well for this
			bysort domac: egen dec_hhginc_pu_hh = total(dec_hhginc_pu)
			replace dec_hhginc_pu_hh = . if dec_hhginc_pu_hh==0	
			replace dec_hhginc_pu = dec_hhginc_pu_hh if vztah!=1
			drop dec_hhginc_pu_hh
		* aggregate income and benefits in a decile
		bysort dec_hhginc_pu: egen dec_aghhinc_i 		= total(hhweginc_perunit)			if hhnonpen==1 //sum over all household members (not only head) to make the sums of per unit income match the total income in population - this way, I can keep deciles based on per unit income (which I need for futher analysis) and match total population income
		bysort dec_hhginc_pu: egen dec_ahhtotaltax_`t'	= total(we_hhtotaltax_perunit_`t') 	if hhnonpen==1
		bysort dec_hhginc_pu: egen dec_ahhtotalben_`t'	= total(we_hhtotalben_perunit_`t') 	if hhnonpen==1
		bysort dec_hhginc_pu: egen dec_ahhnettax_`t' 	= total(we_hhnettax_perunit_`t') 	if hhnonpen==1
							 egen agg_hhginc_i 			= total(hhweginc_perunit)			if hhnonpen==1
							 egen agg_hhtotaltax_`t'	= total(we_hhtotaltax_perunit_`t')	if hhnonpen==1
							 egen agg_hhtotalben_`t'	= total(we_hhtotalben_perunit_`t')	if hhnonpen==1
							 egen agg_hhnettax_`t'		= total(we_hhnettax_perunit_`t')	if hhnonpen==1
							 **DEL egen agg_hhn				= total(rpkoef) 					if hhnonpen==1
		
		* shares for each decile
		g dec_shr_hhginc_i 			= dec_aghhinc_i/agg_hhginc_i				if hhnonpen==1
		g dec_shr_hhtotaltax_`t' 	= dec_ahhtotaltax_`t'/agg_hhtotaltax_`t'	if hhnonpen==1
		g dec_shr_hhtotalben_`t' 	= dec_ahhtotalben_`t'/agg_hhtotalben_`t'	if hhnonpen==1
		g dec_shr_hhnettax_`t' 		= dec_ahhnettax_`t'/agg_hhnettax_`t'		if hhnonpen==1

		label var dec_hhginc_pu 		"household income decile (based on per unit income)"
		label var dec_aghhinc_i	 		"aggregate household gross income in a decile"
		label var dec_ahhtotaltax_`t'	"aggregate household taxes in a decile, t=`t'"
		label var dec_ahhtotalben_`t'	"aggregate household benefits in a decile, t=`t'"
		label var dec_ahhnettax_`t'		"aggregate household net taxes in a decile, t=`t'"
		label var dec_shr_hhginc_i 		"decile share in household gross income"
		label var dec_shr_hhtotaltax_`t'"decile share in household taxes, t=`t'"
		label var dec_shr_hhtotalben_`t'"decile share in household benefits, t=`t'"
		label var dec_shr_hhnettax_`t'	"decile share in household net taxes, t=`t'"
		label var agg_hhginc			"aggregate household income"
		label var agg_hhtotaltax_`t'	"aggregate household taxes, t=`t'"
		label var agg_hhtotalben_`t'	"aggregate household benefits, t=`t'"
		label var agg_hhnettax_`t'		"aggreage household net taxes, t=`t'"
		**DEL label var agg_hhn				"aggregate number of households (with potential earnings)"

	**** 5.2.3. Potential taxpayers (non-working PTR): aggregate potential income and decile shares
	*generate aggregate imputed income
		g we_mzda_f 				= mzda_f*(round(pkoef))
		g we_mzda_p 				= mzda_p*(round(pkoef))
		egen agg_mzda_f 			= total(we_mzda_f) 			if mzda_f>inclb 		& p==0
		egen agg_mzda_p 			= total(we_mzda_p) 			if mzda_p>(inclb/2) 	& p==0
	*generate imputed income deciles
	xtile dec_wage_imp 		= mzda_f  if mzda_f> inclb & p==0 $wep, nquantiles(10)
	*generate aggregate number of potential taxpayers (non-working potential workers)
	**DEL egen agg_npotential_taxpayers_`s'		= total(rpkoef) 	if mzda_f>inclb & p==0	//rpkoef = round(pkoef)
			
	*** 5.3 Tax intervals - share of taxpayers and incomes in tax intervals
	*** 5.3.1 Variables indicating that a tax rate is between 0-10, 10-20, and so on
	* Include many negative intervals - may be useful for radical reforms
	capture label drop int_taxrate
	label def int_taxrate -60 "< -50%" -50 "-50--40%" -40 "-40--30%" -30 "-30--20%" -20 "-20--10%" -10 "-10-0%" 0 "0-10%" 10 "10-20%" 20 "20-30%" 30 "30-40%" 40 "40-50%" 50 "50-60%" 60 "60-70%" 70 "70-80%" 80 "80-90%" 90 "90-100" 100 "> 100%", replace
	local intvars "ATR_w ATR_b ATR_i hhATR_ben hhATR_tax hhATR_all mtr_tax_w mtr_ben_w mtr_all_w mtr_tax_b mtr_ben_b mtr_all_b mtr_tax_i mtr_ben_i mtr_all_i ptr_tax_w_f ptr_tax_w_p ptr_ben_w_f ptr_ben_w_p ptr_all_w_f ptr_all_w_p ptr_tax_w ptr_ben_w ptr_all_w ptr_tax_b ptr_ben_b ptr_all_b ptr_tax_i ptr_ben_i ptr_all_i"
	foreach v of local intvars {
			g int_`v'_`t' = . 
			replace int_`v'_`t' = -60 if `v'_`t' <-0.5
			replace int_`v'_`t' = 100 if `v'_`t' >=1 & `v'_`t'!= .
			forvalues x = -0.5 (0.1) 0.9 {
				replace int_`v'_`t' = `x'*100 if `v'_`t'>=`x' & `v'_`t'<`x'+0.1
			}
			replace int_`v'_`t' = 0 	if int_`v'_`t'<=0 & int_`v'_`t'>-0.1   //replace -2.78e-15 with 0
			label values int_`v'_`t' int_taxrate
			label var int_`v'_`t' "Interval of the tax rate, `v'"
	}
	
	*** 5.3.2. Share of taxpayers and incomes in tax rate intervals - individual taxes
	* export this to a an extra dataset with 11 rows, using the contract command
	* each row being the tax rate interval
	* each variable being the share of taxpayers or income in that interval for a given tax rate
	save taxbenchars_`t', replace
	
	* Loop over sources and tax rates
	local sources "w b i"
	local intvars "ATR mtr_tax mtr_ben mtr_all ptr_tax ptr_ben ptr_all"
	foreach s of local sources {
		foreach v of local intvars {
			* shares of taxpayers (weight by rpkoef)
			use taxbenchars_`t'
			contract int_`v'_`s'_`t' if ginc_`s' > inclb [fw=rpkoef], percent(shrn_`v'_`s'_`t') nomiss
			* renaming the interval variable with a common name
			rename int_`v'_`s'_`t' int_taxrate
			* dropping the frequency counts, labeling, sorting, saving
			drop _freq 							
			label var shrn_`v'_`s'_`t' "Share of taxpayers in the tax rate interval, `v'_`s'"
			sort int_taxrate
			save int_shrn_`v'_`s'_`t', replace 
			
			* shares of incomes (weight by rpkoef multiplied by income)
			use taxbenchars_`t'
			contract int_`v'_`s'_`t' if ginc_`s' > inclb [fw=round(rpkoef*ginc_`s'/100000)], percent(shri_`v'_`s'_`t') nomiss 
			* renaming the interval variable with a common name
			rename int_`v'_`s'_`t' int_taxrate	
			* dropping the frequency counts, labeling, sorting, saving
			drop _freq 							
			label var shri_`v'_`s'_`t' "Share of income in the tax rate interval, `v'_`s'"
			sort int_taxrate
			save int_shri_`v'_`s'_`t', replace 
		}
	}
	
	* Merge the datasets together, starting with ATR_w
	use int_shrn_ATR_w_`t'
	drop shrn_ATR_w_`t'
	save wintervals_`t', replace
	local intvars "ATR_w ATR_b ATR_i mtr_tax_w mtr_ben_w mtr_all_w mtr_tax_b mtr_ben_b mtr_all_b mtr_tax_i mtr_ben_i mtr_all_i ptr_tax_w ptr_ben_w ptr_all_w ptr_tax_b ptr_ben_b ptr_all_b ptr_tax_i ptr_ben_i ptr_all_i"
	foreach v of local intvars {
		merge 1:1 int_taxrate using int_shrn_`v'_`t', nogen
		merge 1:1 int_taxrate using int_shri_`v'_`t', nogen
		erase int_shrn_`v'_`t'.dta
		erase int_shri_`v'_`t'.dta
	}
	sort int_taxrate
	save wintervals_`t', replace
	use taxbenchars_`t'
	
	**** 5.3.3. Share of potential taxpayers (non-working) in PTR intervals
	local jobs = "f p"
	foreach j of local jobs {
		local intvars "ptr_tax_w ptr_ben_w ptr_all_w"
		foreach v of local intvars {
			
			* shares of taxpayers (weight by rpkoef)
			use taxbenchars_`t'
			contract int_`v'_`j'_`t' if mzda_`j' > inclb & p==0 [fw=rpkoef], percent(shrn_`v'_`j'_`t') nomiss
			rename int_`v'_`j'_`t' int_taxrate
			drop _freq 							
			label var shrn_`v'_`j'_`t' "Share of potential taxpayers in the tax rate interval, `v'_`j'"
			sort int_taxrate
			save int_shrn_`v'_`j'_`t', replace 
			
			* shares of potential wages (weight by rpkoef multiplied by imputed wage)
			use taxbenchars_`t'
			contract int_`v'_`j'_`t' if mzda_`j' > inclb & p==0 [fw=round(we_mzda_`j'/100000)], percent(shri_`v'_`j'_`t') nomiss 
			rename int_`v'_`j'_`t' int_taxrate	
			drop _freq 							
			label var shri_`v'_`j'_`t' "Share of imputed income in the tax rate interval, `v'_`j'"
			sort int_taxrate
			save int_shri_`v'_`j'_`t', replace 
		}
	}
	
	* Append the dataset with tax rate intervals with ptr's for non-working
	use wintervals_`t', replace
	local intvars "ptr_tax_w_f ptr_ben_w_f ptr_all_w_f ptr_tax_w_p ptr_ben_w_p ptr_all_w_p"
	foreach v of local intvars {
		merge 1:1 int_taxrate using int_shrn_`v'_`t', nogen
		merge 1:1 int_taxrate using int_shri_`v'_`t', nogen
		erase int_shrn_`v'_`t'.dta
		erase int_shri_`v'_`t'.dta
	}
	sort int_taxrate
	save wintervals_`t', replace
	use taxbenchars_`t'
			
	*** 5.3.3. Share of households in each tax rate interval (only households with potential earnings, i.e., non-pensioners)
	local intvars "hhATR_tax hhATR_ben hhATR_all"
	foreach v of local intvars {
		* shares of households (weight by rpkoef)
		use taxbenchars_`t'
		contract int_`v'_`t' if vztah==1 & hhnonpen==1 [fw=rpkoef], percent(shrn_`v'_`t') nomiss
		rename int_`v'_`t' int_taxrate
		drop _freq 							
		label var shrn_`v'_`t' "Share of households in the tax rate interval, `v'"
		sort int_taxrate
		save int_shrn_`v'_`t', replace 
		
		* shares of household income (weight by hh gross income multiplied by rpkoef)
		use taxbenchars_`t'
		contract int_`v'_`t' if vztah==1 & hhnonpen==1 [fw=round(hhwe_ginc_i/100000)], percent(shri_`v'_`t') nomiss 
		rename int_`v'_`t' int_taxrate	
		drop _freq 							
		label var shri_`v'_`t' "Share of household income in the tax rate interval, `v'"
		sort int_taxrate
		save int_shri_`v'_`t', replace 
	}
	
	* Append the dataset with tax rate intervals with ATRs for households
	use wintervals_`t', replace
	local intvars "hhATR_tax hhATR_ben hhATR_all"
	foreach v of local intvars {
		merge 1:1 int_taxrate using int_shrn_`v'_`t', nogen
		merge 1:1 int_taxrate using int_shri_`v'_`t', nogen
		erase int_shrn_`v'_`t'.dta
		erase int_shri_`v'_`t'.dta
	}
	sort int_taxrate
	save wintervals_`t', replace
	use taxbenchars_`t'
	
	**** 5.4. LORENZ CURVES 
	* Store the values (percentiles at the x and y axix) with individual observations -  useful for future plots etc
	* 5.4.1. Lorenz curves at individual level
	local sources "w b i"
	foreach s of local sources {
		* income 
		glcurve ginc_`s' if ginc_`s' > inclb $wep, lorenz pvar(pvar_ginc_`s') glvar(glvar_ginc_`s') replace
		* total tax against income
		glcurve totaltax_`s'_`t' if ginc_`s' > inclb $wep, sortvar(ginc_`s') lorenz pvar(pvar_ginc_`s') glvar(glvar_totaltax_`s'_`t') replace
	}
	
	* 5.4.2. Lorenz curves at household level (income and net taxes per unit)
	* household income per unit
	glcurve hhginc_perunit if vztah==1 & hhnonpen==1 $wep, sortvar(hhginc_perunit) lorenz pvar(pvar_hhginc_pu) glvar(glvar_hhginc_pu) replace
	* household net taxes per unit
	glcurve hhnettax_perunit_`t' if vztah==1 & hhnonpen==1 $wep, sortvar(hhginc_perunit) lorenz pvar(pvar_hhginc_pu) glvar(glvar_hhnettax_pu_`t') replace
		
	*** 6. TAX REVENUES AND BENEFIT PAYMENTS
	* 6.1 TAXES - BY TYPE OF TAX AND AGGREGATES
		
	* calculate aggregate revenues in millions - variables rev_taxtype_source_t
	* !!! QUESTION: shall we break down into employee/employer payroll? (not economically interesting, but some peple may want to know)
	local sources "w b i"
	local taxtypes "inctax ssp healthp totaltax" 
	foreach x of local taxtypes {
		foreach s of local sources {
			sum `x'_`s'_`t' $wep
			g rev_`x'_`s'_`t' = round(r(sum)/1000000)
		}
	}
	
	label var rev_inctax_w_`t' 		"income tax revenue, work income, t=`t'"
	label var rev_inctax_b_`t' 		"income tax revenue, business income, t=`t'"
	label var rev_inctax_i_`t' 		"total income tax revenue, t=`t'"
	label var rev_ssp_w_`t' 		"social security insurance revenue, work income, t=`t'"
	label var rev_ssp_b_`t' 		"social security insurance revenue, business income, t=`t'"
	label var rev_ssp_i_`t' 		"total social security insurance revenue, t=`t'"
	label var rev_healthp_w_`t' 	"health insurance revenue, work income, t=`t'"
	label var rev_healthp_b_`t' 	"health insurance revenue, business income, t=`t'"
	label var rev_healthp_i_`t' 	"total health insurance revenue, t=`t'"
	label var rev_totaltax_w_`t'	"total taxes on work income, t=`t'"
	label var rev_totaltax_b_`t'	"total taxes on business income, t=`t'"
	label var rev_totaltax_i_`t'	"total taxes on all income, t=`t'"
			
	* 6.2 BENEFIT EXPENDITURES - BY TYPE
	* calculated benefits: birth grant, maternity benefit, child allowance, housing allowance, living allowance, housing supplement
	* benefits taken from the data: parental allowance, unemployment benefit, other benefits (zahrnuje pspvek na pi, vsluhov pspvek, odchodn, pspvky pro tce zdravotn postien obany)
	
	local bentypes "brth_gr mat_ben ch_all hous_ben liv_all hous_supl unempl_ben par_all other_ben mat_need" 
		foreach x of local bentypes {
			sum `x'hh_`t' $wep if vztah==1
			g exp_`x'_`t' = round(r(sum)/1000000) if vztah==1 & hhnonpen==1
		}
	local bentypes2 "brth_gr ch_all hous_ben unempl_ben par_all other_ben mat_need" 
		foreach x of local bentypes2 {
			* the same for reported values as a consistency check
			sum `x'hh_c $wep if vztah==1 //benefits hh assigned to all households members - take only value for head
			g exp_`x'_c = round(r(sum)/1000000) if vztah==1 & hhnonpen==1			
		}
	* total benefit expenditure
	sum hhtotalben_`t' $wep if vztah==1
	g exp_totalben_`t' = round(r(sum)/1000000) if vztah==1 & hhnonpen==1
	sum hhtotalben_c $wep if vztah==1
	g exp_totalben_c = round(r(sum)/1000000) if vztah==1 & hhnonpen==1
	
	label var exp_brth_gr_`t' 		"birth grant expenditures, t=`t'"
	label var exp_mat_ben_`t' 		"maternity benefit expenditures, t=`t'"
	label var exp_ch_all_`t' 		"child allowance expenditures, t=`t'"
	label var exp_hous_ben_`t' 		"housing benefit expenditures, t=`t'"
	label var exp_liv_all_`t' 		"living allowance expenditures, t=`t'"
	label var exp_hous_supl_`t' 	"housing supplement expenditures, t=`t'"
	label var exp_unempl_ben_`t' 	"unemployment benefits expenditures, reported t=c"
	label var exp_par_all_`t' 		"parental allowance expenditures, reported t=c"
	label var exp_other_ben_`t' 	"other benefits expenditures, reported t=c"
	label var exp_totalben_`t'		"total benefit expenditures, t=`t'"
	sort domac osoba
	save taxbenchars_`t', replace
	cd ..
end // end program taxbenchars
