* Files in the directory needed to run the do file: taxbenchars_`u'_`t' 

*** THIS DO FILE PRESENTS IN GRAPHS THE COMPARISON BETWEEN TWO TAX REGIMES, u and t 
*   THE FIRST PART IS THE SAME AS FOR THE LEVEL AND PRESENTS THE CHANGE IN CHARACTERISTICS (MTRs, PTRs etc)
*   (the only difference is in graph titles)
* 	THE SECOND PART PRESENTS THE CHARACTERISTICS IN A SINGLE GRAPH
*   In the program, the argument is `t', hence when calling the program to evaluate the reform, it must be entered as `u'_`t', e.g. 3_z 

/*Program for plotting results (etbgraph) - common for levels and reforms

Parameters (optional parameters in brackets)
	- namelist: list of variables to be plotted. If more varaibles used at a time, all the plots will have the same
	independent variable. Also, if specific titles or labels are used, all the plots will get the same ones (so in this
	case, it is not useful to call the program wih more variables at a time).
	-[if]: optional if expression allowed
Options
	- [xvar(string)]: name of independent variable. If not specified, it will be ginc (gross income).
	- [mode(string)]: 3 possibilities: scatter, kdensity, lpoly (equiv. to Stata commands). Default option: scatter
	- [xlb(int)]: lower bound for independent (x) variable (default 10,000)
	- [xub(int)]: upper bound for independent (x) variable (default 2,000,000)
	- [ylb(int)]: lower bound for dependent (y) variable (default -10,000,000)
	- [yub(int)]: upper bound for dependent (y) variable (default 10,000,000)
	- [title(string)]: title of the plot (by default, the name of the dependent variable)
	- [subtitle(string)]: subtitle of the plot
	- [label(string)]: label of the plot (the same use as with twoway command)
	
Examples:
1) Using all the available options/parameters
	etbgraph totaltax0 if vek>0, xvar(ginc_i) xlb(10000) xub(2000000) ylb(5000) yub(150000) title("TITLE") subtitle("SUBTITLE") label("LABEL")
2) The minimum syntax example
	etbgraph inctax0
3) Example of plotting more variables at a time
	etbgraph inctax0 netinc0
*/
capture program drop etbgraph
program define etbgraph
syntax namelist [if/], [xvar(string) mode(string) xlb(int 7999) xub(int 2000000) ylb(int -10000000) yub(int 10000000) title(string) subtitle(string) label(string)]

//Checking whether independent variable (xvar) is specified. If not, take it to be ginc_i.
if "`xvar'"==""{
local xvar "ginc_i" //default option for independent variable
}


//If there is an if condition, put "&" at the beginning of the macro.
//This is just an easy way of handling both the case when if condition is given and when it is not.
//Needed because we already have some if conditions specified for plotting (bounds).
if "`if'"!=""{
local if "& `if'"
}

if "`mode'"==""{ //default mode: scatter plot
local mode "scatter"
}

if "`title'"==""{
local titlenotdefined 1
//necessary in the case of plotting multiple variables at a time when title not specified (otherwise
//all plots would have the same title - name of the first variable)
}
if "`subtitle'"==""{
local subtitlenotdefined 1
}

foreach var of local namelist{
//If no title given, it is taken to be the name of the dependent variable
if "`titlenotdefined'"~=""{
local title "`var'"
}

//plotting - one of 3 possibilities: scatter plot, kdensity, or lpoly
if "`mode'"=="scatter"{ 
twoway (scatter `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' ///
, legend(label(1 "`label'"))), saving(`var', replace) title("`title'") sub("`subtitle'") 
}

if "`mode'"=="lpoly_scatter"{
//1) Weighted by pkoef (peerson=weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by persons"
}
lpoly `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' [fw=round(pkoef)] ///
,bw(5000) title("`title'") sub("`subtitle'") saving("`var'", replace)
}

if "`mode'"=="lpoly"{
//1) Weighted by pkoef (peerson=weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by persons"
}
lpoly `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' [fw=round(pkoef)] ///
,noscatter bw(5000) title("`title'") sub("`subtitle'") saving("lpoly`var'", replace)

//2) Weighted by pkoef*xvariable (by default: pkoef*ginc_i) (income-weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by income"
}
lpoly `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' [fw=round(pkoef*`xvar')] ///
,noscatter bw(5000) title("`title'") sub("`subtitle'") saving("lpoly`var'incomeweight", replace)
}

//kdensity -> in this case, xvar used only for bounds! Again, plot both person-weighted and income-weighted.

if "`mode'"=="kdensity"{
//1) Weighted by pkoef (peerson=weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by persons"
}
kdensity `var' if `xvar' > `xlb' & `xvar' < `xub' `if' [fw=round(pkoef)] ///
,title("`title'") sub("`subtitle'") saving("kdensity`var'", replace)

//2) Weighted by pkoef*xvariable (by default: pkoef*ginc_i) (income-weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by income"
}
kdensity `var' if `xvar' > `xlb' & `xvar' < `xub' `if' [fw=round(pkoef*`xvar')] ///
,title("`title'") sub("`subtitle'") saving("kdensity`var'incomeweight", replace)
}

}

end

* Executing the plots and summary tables
capture program drop reformplots
program define reformplots
args t 
	set more off
	cd output_`t' //directories for storing the output
	use taxbenchars_`t', clear
	capture mkdir plots_`t' 
	cd plots_`t'
	
	***plots of ATR's***	
	etbgraph pATR_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in average tax rate, work income, `t'") subtitle("All income and payroll taxes")
	etbgraph pATR_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in average tax rate, business income, `t'") subtitle("All income and payroll taxes")
	etbgraph pATR_i_`t', xvar("ginc_i") mode(lpoly_scatter) title("Change in average tax rate, all income, `t'") subtitle("All income and payroll taxes")
	
	*** HH-level: plots of household level ATRs (including benefits)***
	** these graphs do not say much...
	etbgraph phhATR_tax_`t' if vztah==1 & hhnonpen==1 , xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in HH-level average tax rate on all income, `t'") subtitle("Households with positive income only")
	etbgraph phhATR_ben_`t' if vztah==1 & hhnonpen==1 , xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in HH-level average benefit rate on all income, `t'") subtitle("Households with positive income only")
	etbgraph phhATR_all_`t' if vztah==1 & hhnonpen==1 , xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in HH-level average net tax rate on all income, `t'") subtitle("Households with positive income only")

	***plots of total tax as a fn of income***
	etbgraph totaltax_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in total tax on work income, `t'") subtitle("All income and payroll taxes") 
	etbgraph totaltax_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in total tax on business income, `t'") subtitle("All income and payroll taxes") 
	etbgraph totaltax_i_`t', xvar("ginc_i") mode(lpoly_scatter) title("Change in total tax on all income, `t'") subtitle("All income and payroll taxes") 

	*** HH-level: plots of total taxes and benefits as a fn of income***
	etbgraph hhtotaltax_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in total household taxes per OECD unit, `t'") subtitle("All households") 
	etbgraph hhtotalben_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in total household benefits per OECD unit, `t'") subtitle("All households") 
	etbgraph hhnettax_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in total household net taxes per OECD unit, `t'") subtitle("All households") 
	
	*** HH-level: plots of net income as a fn of income, and its percentage change ***
	etbgraph hhnetinc_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Change in household net income per OECD unit, `t'") subtitle("All households") 
	etbgraph pd_hhnetinc_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Percentage change in household net income, `t'") subtitle("All households") 
	
	
	**** plots of average ATRs as fn of income
	etbgraph pATR_w_`t', xvar("ginc_w") mode(lpoly) title("Change in average ATR, work income (kernel smoothing), `t'")
	etbgraph pATR_b_`t', xvar("ginc_b") mode(lpoly) title("Change in average ATR, business income (kernel smoothing), `t'")
	etbgraph pATR_i_`t', xvar("ginc_i") mode(lpoly) title("Change in average ATR, all income (kernel smoothing), `t'")
	
	
	*** plots of kernel density of ATR ***
	etbgraph pATR_w_`t', xvar("ginc_w") mode(kdensity) title("Kernel density of change in ATR on work income, `t'")
	etbgraph pATR_b_`t', xvar("ginc_b") mode(kdensity) title("Kernel density of change in ATR on business income, `t'")
	etbgraph pATR_i_`t', xvar("ginc_i") mode(kdensity) title("Kernel density of change in ATR on all income, `t'")
	
	*** plot of kernel density of income ***
	etbgraph ginc_w , xvar("ginc_w") mode(kdensity) title("Kernel density of gross work income")
	etbgraph ginc_b , xvar("ginc_b") mode(kdensity) title("Kernel density of gross business income")
	etbgraph ginc_i , xvar("ginc_i") mode(kdensity) title("Kernel density of gross income (work+business)")
	
	*** plots of MTR's - tax only
	etbgraph pmtr_tax_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in marginal tax rate, work income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_tax_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in marginal tax rate, business income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_tax_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Change in marginal tax rate, all income, `t'") subtitle("All income and payroll taxes")

	*** plots of MTR's - full 
	etbgraph pmtr_all_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in effective marginal tax rate, work income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_all_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in effective marginal tax rate, business income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_all_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Change in effective marginal tax rate, all income, `t'") subtitle("All income and payroll taxes")

	*** plots of PTR's - tax only
	etbgraph pptr_tax_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in participation tax rate, work income, `t'") subtitle("Income tax and payroll taxes")
	etbgraph pptr_tax_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in participation tax rate, business income, `t'") subtitle("Income tax and payroll taxes")
	etbgraph pptr_tax_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Change in participation tax rate, all income, `t'") subtitle("Income tax and payroll taxes")
	
	*** plots of PTR's - ben only
	etbgraph pptr_ben_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in benefit withdrawal rate, work income, `t'") subtitle("Welfare benefits")
	etbgraph pptr_ben_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in benefit withdrawal rate, business income, `t'") subtitle("Welfare benefits")
	etbgraph pptr_ben_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Change in benefit withdrawal rate, all income, `t'") subtitle("Welfare benefits")

	*** plots of PTR's - full 
	etbgraph pptr_all_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Change in effective participation tax rate, work income, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	etbgraph pptr_all_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Change in effective participation tax rate, business income, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	etbgraph pptr_all_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Change in effective participation tax rate, all income, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")

	*** plots of PTR's - non-working tax only
	etbgraph pptr_tax_w_f_`t', xvar("mzda_f") mode(lpoly_scatter) title("Change in participation tax rate, non-working, full-time, `t'") subtitle("Income tax and payroll taxes")
	etbgraph pptr_tax_w_p_`t', xvar("mzda_p") mode(lpoly_scatter) title("Change in participation tax rate, non-working, part-time, `t'") subtitle("Income tax and payroll taxes")

	*** plots of PTR's - non-working ben only
	etbgraph pptr_ben_w_f_`t', xvar("mzda_f") mode(lpoly_scatter) title("Change in benefit withdrawal rate, non-working, full-time, `t'") subtitle("Welfare benefits")
	etbgraph pptr_ben_w_p_`t', xvar("mzda_p") mode(lpoly_scatter) title("Change in benefit withdrawal rate, non-working, part-time, `t'") subtitle("Welfare benefits")

	*** plots of PTR's - non-working full
	etbgraph pptr_all_w_f_`t', xvar("mzda_f") mode(lpoly_scatter) title("Change in effective participation tax rate, non-working, full-time, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	etbgraph pptr_all_w_p_`t', xvar("mzda_p") mode(lpoly_scatter) title("Change in effective participation tax rate, non-working, part-time, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
		
	cd ../..
	
end //end program reformplots

	